# OrderActionRenewSubscription

Information about an order action of type `RenewSubscription`. 

## Properties

Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**bill_to_contact_id** | **str** | The ID of the bill-to contact associated with the subscription.  **Note**:    - If you have the &lt;a href&#x3D;\&quot;https://knowledgecenter.zuora.com/Zuora_Billing/Bill_your_customers/Bill_customers_at_subscription_level/Flexible_Billing_Attributes\&quot; target&#x3D;\&quot;_blank\&quot;&gt;Flexible Billing Attributes&lt;/a&gt; feature disabled, this field is unavailable in the request body and the value of this field is &#x60;null&#x60; in the response body.    - If you have the Flexible Billing Attributes feature enabled, and you do not specify this field in the request or you select **Default Contact from Account** for this field during subscription creation, the value of this field is automatically set to &#x60;null&#x60; in the response body.  | [optional] 
**clearing_existing_bill_to_contact** | **bool** | Whether to clear the existing bill-to contact ID at the subscription level. This field is mutually exclusive with the &#x60;billToContactId&#x60; field.  **Note**: If you have the [Flexible Billing Attributes](https://knowledgecenter.zuora.com/Billing/Subscriptions/Flexible_Billing_Attributes) feature disabled, this field is unavailable in the request body and the value of this field is &#x60;null&#x60; in the response body.  | [optional] [default to False]
**clearing_existing_invoice_group_number** | **bool** | Whether to clear the existing invoice group number at the subscription level. This field is mutually exclusive with the &#x60;invoiceGroupNumber&#x60; field.  **Note**: If you have the [Flexible Billing Attributes](https://knowledgecenter.zuora.com/Billing/Subscriptions/Flexible_Billing_Attributes) feature disabled, this field is unavailable in the request body and the value of this field is &#x60;null&#x60; in the response body.  | [optional] [default to False]
**clearing_existing_invoice_template** | **bool** | Whether to clear the existing invoice template ID at the subscription level. This field is mutually exclusive with the &#x60;invoiceTemplateId&#x60; field.  **Note**: If you have the [Flexible Billing Attributes](https://knowledgecenter.zuora.com/Billing/Subscriptions/Flexible_Billing_Attributes) feature disabled, this field is unavailable in the request body and the value of this field is &#x60;null&#x60; in the response body.  | [optional] [default to False]
**clearing_existing_payment_term** | **bool** | Whether to clear the existing payment term at the subscription level. This field is mutually exclusive with the &#x60;paymentTerm&#x60; field.  **Note**: If you have the [Flexible Billing Attributes](https://knowledgecenter.zuora.com/Billing/Subscriptions/Flexible_Billing_Attributes) feature disabled, this field is unavailable in the request body and the value of this field is &#x60;null&#x60; in the response body.  | [optional] [default to False]
**clearing_existing_sequence_set** | **bool** | Whether to clear the existing sequence set ID at the subscription level. This field is mutually exclusive with the &#x60;sequenceSetId&#x60; field.  **Note**: If you have the [Flexible Billing Attributes](https://knowledgecenter.zuora.com/Billing/Subscriptions/Flexible_Billing_Attributes) feature disabled, this field is unavailable in the request body and the value of this field is &#x60;null&#x60; in the response body.  | [optional] [default to False]
**clearing_existing_sold_to_contact** | **bool** | Whether to clear the existing sold-to contact ID at the subscription level. This field is mutually exclusive with the &#x60;soldToContactId&#x60; field.  **Note**: If you have the [Flexible Billing Attributes](https://knowledgecenter.zuora.com/Billing/Subscriptions/Flexible_Billing_Attributes) feature disabled, this field is unavailable in the request body and the value of this field is &#x60;null&#x60; in the response body.  | [optional] [default to False]
**invoice_group_number** | **str** | The number of invoice group associated with the subscription.  **Note**: This field is available only if you have the &lt;a href&#x3D;\&quot;https://knowledgecenter.zuora.com/Zuora_Billing/Bill_your_customers/Bill_customers_at_subscription_level/Flexible_Billing_Attributes\&quot; target&#x3D;\&quot;_blank\&quot;&gt;Flexible Billing Attributes&lt;/a&gt; feature enabled.  | [optional] 
**invoice_template_id** | **str** | The ID of the invoice template associated with the subscription.  **Note**:    - If you have the &lt;a href&#x3D;\&quot;https://knowledgecenter.zuora.com/Zuora_Billing/Bill_your_customers/Bill_customers_at_subscription_level/Flexible_Billing_Attributes\&quot; target&#x3D;\&quot;_blank\&quot;&gt;Flexible Billing Attributes&lt;/a&gt; feature disabled, this field is unavailable in the request body and the value of this field is &#x60;null&#x60; in the response body.    - If you have the Flexible Billing Attributes feature enabled, and you do not specify this field in the request or you select **Default Template from Account** for this field during subscription creation, the value of this field is automatically set to &#x60;null&#x60; in the response body.  | [optional] 
**payment_term** | **str** | The name of the payment term associated with the subscription. For example, &#x60;Net 30&#x60;. The payment term determines the due dates of invoices.  **Note**:    - If you have the &lt;a href&#x3D;\&quot;https://knowledgecenter.zuora.com/Zuora_Billing/Bill_your_customers/Bill_customers_at_subscription_level/Flexible_Billing_Attributes\&quot; target&#x3D;\&quot;_blank\&quot;&gt;Flexible Billing Attributes&lt;/a&gt; feature disabled, this field is unavailable in the request body and the value of this field is &#x60;null&#x60; in the response body.    - If you have the Flexible Billing Attributes feature enabled, and you do not specify this field in the request or you select **Default Term from Account** for this field during subscription creation, the value of this field is automatically set to &#x60;null&#x60; in the response body..  | [optional] 
**sequence_set_id** | **str** | The ID of the sequence set associated with the subscription.    **Note**:    - If you have the &lt;a href&#x3D;\&quot;https://knowledgecenter.zuora.com/Zuora_Billing/Bill_your_customers/Bill_customers_at_subscription_level/Flexible_Billing_Attributes\&quot; target&#x3D;\&quot;_blank\&quot;&gt;Flexible Billing Attributes&lt;/a&gt; feature disabled, this field is unavailable in the request body and the value of this field is &#x60;null&#x60; in the response body.    - If you have the Flexible Billing Attributes feature enabled, and you do not specify this field in the request or you select **Default Set from Account** for this field during subscription creation, the value of this field is automatically set to &#x60;null&#x60; in the response body.  | [optional] 
**sold_to_contact_id** | **str** | The ID of the sold-to contact associated with the subscription.  **Note**:    - If you have the &lt;a href&#x3D;\&quot;https://knowledgecenter.zuora.com/Zuora_Billing/Bill_your_customers/Bill_customers_at_subscription_level/Flexible_Billing_Attributes\&quot; target&#x3D;\&quot;_blank\&quot;&gt;Flexible Billing Attributes&lt;/a&gt; feature disabled, this field is unavailable in the request body and the value of this field is &#x60;null&#x60; in the response body.    - If you have the Flexible Billing Attributes feature enabled, and you do not specify this field in the request or you select **Default Contact from Account** for this field during subscription creation, the value of this field is automatically set to &#x60;null&#x60; in the response body.  | [optional] 
**ship_to_contact_id** | **str** | The ID of the ship-to contact associated with the subscription.  | [optional] 
**clearing_existing_ship_to_contact** | **bool** | Whether to clear the existing ship-to contact ID at the subscription level. This field is mutually exclusive with the &#x60;shipToContactId&#x60; field.  | [optional] 

## Example

```python
from zuora_sdk.models.order_action_renew_subscription import OrderActionRenewSubscription

# TODO update the JSON string below
json = "{}"
# create an instance of OrderActionRenewSubscription from a JSON string
order_action_renew_subscription_instance = OrderActionRenewSubscription.from_json(json)
# print the JSON string representation of the object
print(OrderActionRenewSubscription.to_json())

# convert the object into a dict
order_action_renew_subscription_dict = order_action_renew_subscription_instance.to_dict()
# create an instance of OrderActionRenewSubscription from a dict
order_action_renew_subscription_from_dict = OrderActionRenewSubscription.from_dict(order_action_renew_subscription_dict)
```
[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


